require "cocoapods"

if Gem::Dependency.new("", '>= 0.39').match?('', Pod::VERSION)
    require 'pod/command/repo_rsync'
    require 'pod/podfile/dsl'
    require 'rsync_source'

    # This pre_install hook requires cocoapods v. 0.38.0.beta.2 or higher
    Pod::HooksManager.register('cocoapods-repo-rsync', :source_provider) do |context, options|
        Pod::UI.message 'cocoapods-repo-rsync received source_provider hook'
        return unless sources = options['sources']
        sources.each do |source|
            url, ssh_argv ,skip= source
            url = url + "/" unless url.end_with?("/")
            source = Pod::RsyncSource.rsync_source_by_url(url)
            if source
                update = true
                # CP 1.0.0 not support
                update = !Pod::Config.instance.skip_repo_update if Gem::Dependency.new("", '~> 0.39').match?('', Pod::VERSION)
                if update
                    if File.writable?(source.repo)
                        argv = CLAide::ARGV.new([source.name, ssh_argv,skip])
                        Pod::Command::RepoRsync::Update.new(argv).run()
                    else
                        Pod::UI.puts "#{source.name} is readonly, skip update."
                    end
                end
            else
                argv = CLAide::ARGV.new([name_for_url(url), url, ssh_argv,skip])
                Pod::Command::RepoRsync::Add.new(argv).run()
                source = Pod::RsyncSource.rsync_source_by_url(url)
            end
            context.add_source(source) if source
        end
    end

    # @param [String] url The URL of the RSYNC repository
    #
    # @return [String] a name for the repository
    #
    # For now, this uses the host and the last component of the URL as the name
    # So spec@my.server.com:/home/spec will return my-server-com-spec
    def name_for_url(url)
        host, path = url.split(":")
        path = path.split("/").last
        return path.gsub(".", "-").downcase
    end
end
