require 'fileutils'
require 'cocoapods-repo-rsync'

module Pod
  class Command
    module Options
      # Provides support for commands to skip updating the spec repositories.
      #
      module RepoUpdate
        module Options
          def options
            [
                ['--no-repo-update', 'Skip running `pod repo update` before install'],
            ].concat(super)
          end
        end

        def self.included(base)
          base.extend(Options)
        end

        def repo_update?(default: false)
          if @repo_update.nil?
            default
          else
            @repo_update
          end
        end

        def initialize(argv)
          @repo_update = argv.flag?('repo-update')
          print "@repo_update #{@repo_update} \n"
          if !@repo_update.nil?
            ENV["NO_REPO_UPDATE"]="true"
          end
          super
        end
      end
    end

    class RepoRsync < Command


      require 'pod/command/repo_rsync/add'
      require 'pod/command/repo_rsync/update'

      self.abstract_command = true
      self.summary = <<-SUMMARY
        Manage your Cocoapod spec repositories using subversion - v#{CocoapodsRepoRsync::VERSION}
      SUMMARY

      extend Executable
      executable :rsync

      def dir
        config.repos_dir + @name
      end
    end
  end
end
